Learn R Programming

voigt (version 2.0)

voigt-package: Tools for working with the Voigt distribution

Description

tools:::Rd_package_description("voigt")

Arguments

Author

tools:::Rd_package_author("voigt")

Maintainer: tools:::Rd_package_maintainer("voigt")

Details

The package contains functions for working with the Voigt distribution in the R environment:

rvoigt generates random variates

dvoigt calculates voigt density

evoigt estimates parameters following a Bayesian approach

otherwise unavailable within R (R < 4.4.1). The main function evoigt provides both point and interval estimates for the Voigt parameters using a Bayesian approach.

References

Kendall, D. G. (1938). The effect of radiation damping and Doppler broadening on the atomic absorption coefficient. Zeitschrift fur Astrophysik, Vol. 16, p.308 https://adsabs.harvard.edu/full/1938ZA.....16..308K

Cannas, M. and Piras, N. Mixture representation and parameter estimation for the Voigt profile (submitted)

Examples

Run this code
if (FALSE) {
##  See examples in the help file of each function.
    }

Run the code above in your browser using DataLab