The package contains functions for working with the Voigt distribution in the R environment:
rvoigt generates random variates
dvoigt calculates voigt density
evoigt estimates parameters following a Bayesian approach
otherwise unavailable within R (R < 4.4.1). The main function evoigt provides both point and interval estimates for the Voigt parameters using a Bayesian approach.